@@ -984,7 +984,7 @@ static bool RemoveAdvancedLastArg(string & str, string & arg)
 //#endif
 int i, j;
 char c, LastC;
-BYTE LastSupSub, LastCBrace;
+uint8_t LastSupSub, LastCBrace;
 
   LastCBrace=LastSupSub=LastC=0;
   arg.erase();
@@ -1488,7 +1488,7 @@ bool OptimizeFormulaStr(TconvertedPass1 *cq, string & StrBeg)
 {
 int i, j;
 string StrEnd, arg[3];
-BYTE styles;
+uint8_t styles;
 
   StrBeg.trim();
   if(((length(StrBeg)>2) && (StrBeg[length(StrBeg)-2]!='\\'))   //fix one error when equation end with dollar $
