@@ -418,7 +418,7 @@ TImageFileHandler TIFF_H(".TIFF",
 #endif
 
 
-#ifdef SupportWMF
+#if defined(SupportWPG) && SupportWMF>=2
  ImplementReader(WMF,".WMF")
  #if SupportWMF>=4 || SupportWMF==2
 	LoadPictureWMF,
