@@ -51,7 +51,7 @@
  #define SupportTIFF 2
  #define SupportTXT 2	//Read procedure only
  #define SupportTXTgm 2
- #define SupportWMF 2
+ #define SupportWMF 1	//Use another WMF reader.
  #define SupportWPG 1	//Compile only supporting stub, build-in reader included
  #define SupportXPM 2
 #endif
