@@ -1,5 +1,5 @@
 /******************************************************************************
- * Unit:    raster            release 0.23                                    *
+ * Unit:    raster            release 0.25                                    *
  * Prototype declaration of separate classes. Normally this is not needed     *
  * to be included.                                                            *
  * licency:     GPL or LGPL                                                   *
@@ -9,6 +9,8 @@
 #define _RAS_PROT_H_
 
 //#define OPTIMISE_SPEED
+#include "raster.h"
+
 
 #ifdef _MSC_VER
  #pragma warning (push)
@@ -23,11 +25,11 @@ class Raster1D_1Bit: virtual public Raster1DAbstract
 	{
 public: virtual int GetPlanes(void) const {return(1);};
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
-        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 #endif
 #ifdef OPTIMISE_SPEED
 	virtual void Get(Raster1DAbstract &R1) const;
@@ -41,11 +43,11 @@ class Raster1D_2Bit: virtual public Raster1DAbstract
 	{
 public: virtual int GetPlanes(void) const {return(2);};
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
-        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 #endif
 	};
 
@@ -55,11 +57,11 @@ class Raster1D_4Bit: virtual public Raster1DAbstract
 	{
 public: virtual int GetPlanes(void) const {return(4);};
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
-        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 #endif
 
 #ifdef OPTIMISE_SPEED
@@ -87,12 +89,12 @@ public:	Raster1D_8Bit(int InitSize1D) {if((Data1D=malloc(InitSize1D))!=NULL) Siz
 	virtual void Get(Raster1DAbstract &R1) const;
 #endif	//OPTIMISE_SPEED
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
-        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
         virtual double PTR_GetValue1Dd(const void *RAW_Data1D, unsigned x) const;
 	virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) const;	
 #endif
@@ -114,11 +116,11 @@ public: Raster1D_16Bit(int InitSize1D) {if((Data1D=malloc(2*InitSize1D))!=NULL)
 
 	virtual int GetPlanes(void) const {return(16);};
 
-	virtual DWORD GetValue1D(unsigned x) const {if(Size1D<=x) return(0); return(((WORD *)Data1D)[x]);};
-	virtual void SetValue1D(unsigned x, DWORD NewValue) {if(Size1D<=x) return; ((WORD *)Data1D)[x]=(WORD)NewValue;};
+	virtual uint32_t GetValue1D(unsigned x) const {if(Size1D<=x) return(0); return(((uint16_t *)Data1D)[x]);};
+	virtual void SetValue1D(unsigned x, uint32_t NewValue) {if(Size1D<=x) return; ((uint16_t *)Data1D)[x]=(uint16_t)NewValue;};
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
-        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 	virtual double PTR_GetValue1Dd(const void *RAW_Data1D, unsigned x) const;
 	virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) const;
 #endif
@@ -149,11 +151,11 @@ class Raster1D_24Bit:virtual public Raster1DAbstract
 	{
 public: virtual int GetPlanes(void) const {return(24);};
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
-	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 #endif
 #ifdef OPTIMISE_SPEED
 	virtual void Get(Raster1DAbstract &R1) const;
@@ -161,8 +163,8 @@ public: virtual int GetPlanes(void) const {return(24);};
 #endif
 	virtual void Get24BitRGB(void *Buffer24Bit) const;
 
-	virtual void Peel8Bit(BYTE *Buffer8Bit, char plane8) const;
-	virtual void Join8Bit(BYTE *Buffer8Bit, char plane8);
+	virtual void Peel8Bit(uint8_t *Buffer8Bit, char plane8) const;
+	virtual void Join8Bit(uint8_t *Buffer8Bit, char plane8);
 	};
 
 
@@ -171,12 +173,12 @@ class Raster1D_32Bit:virtual public Raster1DAbstract
 	{
 public: virtual int GetPlanes(void) const {return(32);};
 
-	virtual DWORD GetValue1D(unsigned x) const {if(x<Size1D) return(((DWORD *)Data1D)[x]); return(0);};
-	virtual void SetValue1D(unsigned x, DWORD NewValue) {if(x<Size1D) ((DWORD *)Data1D)[x]=NewValue; return;};
+	virtual uint32_t GetValue1D(unsigned x) const {if(x<Size1D) return(((uint32_t *)Data1D)[x]); return(0);};
+	virtual void SetValue1D(unsigned x, uint32_t NewValue) {if(x<Size1D) ((uint32_t *)Data1D)[x]=NewValue; return;};
 	virtual void SetValue1Dd(unsigned x, double NewValue);
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
-        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
         virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) const;
 #endif
 #ifdef OPTIMISE_SPEED
@@ -186,20 +188,20 @@ public: virtual int GetPlanes(void) const {return(32);};
 	};
 
 
-#ifdef QWORD
+#if defined(uint64_t) || defined(uint64_t_defined)
 /** 64 bit planes */
 class Raster1D_64Bit:virtual public Raster1DAbstract
 	{
 public: virtual int GetPlanes(void) const {return(64);};
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual double GetValue1Dd(unsigned x) const {if(x<Size1D) return((double)((QWORD *)Data1D)[x]); return(0);};
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual double GetValue1Dd(unsigned x) const {if(x<Size1D) return((double)((uint64_t *)Data1D)[x]); return(0);};
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 	virtual void SetValue1Dd(unsigned x, double NewValue);
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
         virtual double PTR_GetValue1Dd(const void *RAW_Data1D, unsigned x) const;
-        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
         virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) const;
 #endif
 #ifdef OPTIMISE_SPEED
@@ -218,14 +220,14 @@ public: float Min, Max;
 
 	virtual int GetPlanes(void) const {return(-32);};
 
-	virtual DWORD GetValue1D(unsigned x) const;
+	virtual uint32_t GetValue1D(unsigned x) const;
 	virtual double GetValue1Dd(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 	virtual void SetValue1Dd(unsigned x, double NewValue);
 #ifdef _REENTRANT
-	virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+	virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
 	virtual double PTR_GetValue1Dd(const void *RAW_Data1D, unsigned x) const;
-	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 	virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) const;
 #endif
 #ifdef OPTIMISE_SPEED
@@ -243,14 +245,14 @@ public: double Min, Max;
 
 	virtual int GetPlanes(void) const {return(-64);};
 
-	virtual DWORD GetValue1D(unsigned x) const;
+	virtual uint32_t GetValue1D(unsigned x) const;
 	virtual double GetValue1Dd(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 	virtual void SetValue1Dd(unsigned x, double NewValue);
 #ifdef _REENTRANT
-	virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
+	virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
 	virtual double PTR_GetValue1Dd(const void *RAW_Data1D, unsigned x) const;
-	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 	virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) const;
 #endif
 #ifdef OPTIMISE_SPEED
@@ -260,16 +262,34 @@ public: double Min, Max;
 };
 
 
-/*
-class Raster1D_5BitRGB: virtual public Raster1D_16Bit, virtual public Raster1DAbstractRGB
+//class Raster1D_5BitRGB: virtual public Raster1D_16Bit, virtual public Raster1DAbstractRGB
+class Raster1D_16Bit565: virtual public Raster1D_16Bit, virtual public Raster1DAbstractRGB
 {
-public:
-	unsigned R(unsigned x) const {return(((WORD*)Data1D)[x]&0x1F);}
-	unsigned G(unsigned x) const {return((((WORD*)Data1D)[x]>>5)&0x1F);}
-	unsigned B(unsigned x) const {return((((WORD*)Data1D)[x]>>10)&0x1F);}
+public: Raster1D_16Bit565(int InitSize1D): Raster1D_16Bit(InitSize1D) {}
+        Raster1D_16Bit565() {}
 
+	virtual unsigned R(unsigned x) const;
+	virtual unsigned G(unsigned x) const;
+	virtual unsigned B(unsigned x) const;
+
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
+	virtual void Get(unsigned index, RGBQuad *RGB) const;
+	virtual void Set(unsigned index, const RGBQuad *RGB);
+
+	//virtual void Get24BitRGB(void *Buffer24Bit) const;
+        virtual uint32_t GetValue1DRAW(unsigned x) const {if(x<Size1D) return(((uint16_t *)Data1D)[x]); return(0);};
+	virtual void SetValue1DRAW(unsigned x, uint32_t NewValue) {if(x<Size1D) ((uint16_t *)Data1D)[x]=NewValue;};
+#ifdef OPTIMISE_SPEED
+	//virtual void Get(Raster1DAbstract &R1) const {Raster1DAbstractRGB::Get(R1);}
+	void Set(const Raster1DAbstract &R1) {Raster1DAbstractRGB::Set(R1);}
+#endif
+#ifdef _REENTRANT
+        virtual uint32_t PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const;
+	virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, uint32_t NewValue);
+#endif
 };
-*/
+
 
 
 /** 8 bit planes for 3 channels R,G,B */
@@ -286,19 +306,19 @@ public:	Raster1D_8BitRGB(int InitSize1D)  {Allocate1D(InitSize1D);};
 
 	virtual void Get24BitRGB(void *Buffer24Bit) const;
 
-	virtual DWORD GetValue1DRAW(unsigned x) const {if(x<3*Size1D) return(((BYTE *)Data1D)[x]); return(0);};
-	virtual void SetValue1DRAW(unsigned x, DWORD NewValue) {if(x<3*Size1D) ((BYTE *)Data1D)[x]=(BYTE)NewValue;};
+	virtual uint32_t GetValue1DRAW(unsigned x) const {if(x<3*Size1D) return(((uint8_t *)Data1D)[x]); return(0);};
+	virtual void SetValue1DRAW(unsigned x, uint32_t NewValue) {if(x<3*Size1D) ((uint8_t *)Data1D)[x]=(uint8_t)NewValue;};
 #ifdef _REENTRANT
-        virtual DWORD PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const 
-            {if(x<3*Size1D) return(((BYTE *)RAW_Data1D)[x]); return(0);};
-	virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, DWORD NewValue)
-            {if(x<3*Size1D) ((BYTE *)RAW_Data1D)[x]=NewValue;};
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const; 
-	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual uint32_t PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const 
+            {if(x<3*Size1D) return(((uint8_t *)RAW_Data1D)[x]); return(0);};
+	virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, uint32_t NewValue)
+            {if(x<3*Size1D) ((uint8_t *)RAW_Data1D)[x]=NewValue;};
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const; 
+	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 #endif
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 	};
 
 
@@ -316,20 +336,20 @@ public:	Raster1D_16BitRGB(int InitSize1D)	{Allocate1D(InitSize1D);}
 
 	virtual void Get24BitRGB(void *Buffer24Bit) const;
 
-        virtual DWORD GetValue1DRAW(unsigned x) const {if(x<3*Size1D) return(((WORD *)Data1D)[x]); return(0);};
-	virtual void SetValue1DRAW(unsigned x, DWORD NewValue) {if(x<3*Size1D) ((WORD *)Data1D)[x]=NewValue;};
+        virtual uint32_t GetValue1DRAW(unsigned x) const {if(x<3*Size1D) return(((uint16_t *)Data1D)[x]); return(0);};
+	virtual void SetValue1DRAW(unsigned x, uint32_t NewValue) {if(x<3*Size1D) ((uint16_t *)Data1D)[x]=NewValue;};
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 
 #ifdef _REENTRANT
 protected:
-        virtual DWORD PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const 
-            {if(x<3*Size1D) return(((WORD *)RAW_Data1D)[x]); return(0);};
-	virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, DWORD NewValue)
-            {if(x<3*Size1D) ((WORD *)RAW_Data1D)[x]=NewValue;};
-        virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const; 
-	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual uint32_t PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const 
+            {if(x<3*Size1D) return(((uint16_t *)RAW_Data1D)[x]); return(0);};
+	virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, uint32_t NewValue)
+            {if(x<3*Size1D) ((uint16_t *)RAW_Data1D)[x]=NewValue;};
+        virtual uint32_t PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const; 
+	virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 #endif
 	};
 
@@ -343,21 +363,21 @@ public:	Raster1D_8BitRGBA(int InitSize1D)  {Allocate1D(InitSize1D);};
 	virtual int GetPlanes(void) const {return(4*8);};
 	virtual unsigned GetSize1D(void) const {return(Size1D);};
 
-	virtual DWORD GetValue1DRAW(unsigned x) const {if(x<4*Size1D) return(((BYTE *)Data1D)[x]); return(0);};
-	virtual void SetValue1DRAW(unsigned x, DWORD NewValue) {if(x<4*Size1D) ((BYTE *)Data1D)[x]=NewValue;};
+	virtual uint32_t GetValue1DRAW(unsigned x) const {if(x<4*Size1D) return(((uint8_t *)Data1D)[x]); return(0);};
+	virtual void SetValue1DRAW(unsigned x, uint32_t NewValue) {if(x<4*Size1D) ((uint8_t *)Data1D)[x]=NewValue;};
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);
 	virtual void Get(unsigned x, RGBQuad *RGB) const;
 	void Get24BitRGB(void *Buffer24Bit) const;
 
 #ifdef _REENTRANT
-        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 protected:
-        virtual DWORD PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const 
-            {if(x<4*Size1D) return(((BYTE *)RAW_Data1D)[x]); return(0);};
-	virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, DWORD NewValue) 
-            {if(x<4*Size1D) ((BYTE *)RAW_Data1D)[x]=NewValue;};
+        virtual uint32_t PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const 
+            {if(x<4*Size1D) return(((uint8_t *)RAW_Data1D)[x]); return(0);};
+	virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, uint32_t NewValue) 
+            {if(x<4*Size1D) ((uint8_t *)RAW_Data1D)[x]=NewValue;};
 #endif
 	};
 
@@ -371,19 +391,19 @@ public:	Raster1D_16BitRGBA(int InitSize1D)	{Allocate1D(InitSize1D);}
 	virtual unsigned GetSize1D(void) const {return(Size1D);};
 	virtual int GetPlanes(void) const {return(4*16);};
 
-        virtual DWORD GetValue1DRAW(unsigned x) const {if(x<4*Size1D) return(((WORD *)Data1D)[x]);return(0);};
-	virtual void SetValue1DRAW(unsigned x, DWORD NewValue) {if(x<4*Size1D) ((WORD *)Data1D)[x]=NewValue;};
+        virtual uint32_t GetValue1DRAW(unsigned x) const {if(x<4*Size1D) return(((uint16_t *)Data1D)[x]);return(0);};
+	virtual void SetValue1DRAW(unsigned x, uint32_t NewValue) {if(x<4*Size1D) ((uint16_t *)Data1D)[x]=NewValue;};
 
-	virtual DWORD GetValue1D(unsigned x) const;
-	virtual void SetValue1D(unsigned x, DWORD NewValue);	
+	virtual uint32_t GetValue1D(unsigned x) const;
+	virtual void SetValue1D(unsigned x, uint32_t NewValue);	
 
 #ifdef _REENTRANT
-        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
+        virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const;
 protected:
-        virtual DWORD PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const 
-            {if(x<4*Size1D) return(((WORD *)RAW_Data1D)[x]);return(0);};
-	virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, DWORD NewValue) 
-            {if(x<4*Size1D) ((WORD *)RAW_Data1D)[x]=NewValue;};
+        virtual uint32_t PTR_GetValue1DRAW(const void *RAW_Data1D, unsigned x) const 
+            {if(x<4*Size1D) return(((uint16_t *)RAW_Data1D)[x]);return(0);};
+	virtual void PTR_SetValue1DRAW(void *RAW_Data1D, unsigned x, uint32_t NewValue) 
+            {if(x<4*Size1D) ((uint16_t *)RAW_Data1D)[x]=NewValue;};
 #endif
 };
 
@@ -397,7 +417,7 @@ class Raster2D_8Bit: virtual public Raster2DAbstract, public Raster1D_8Bit {};
 class Raster2D_16Bit:virtual public Raster2DAbstract, public Raster1D_16Bit {};
 class Raster2D_24Bit:virtual public Raster2DAbstract, public Raster1D_24Bit {};
 class Raster2D_32Bit:virtual public Raster2DAbstract, public Raster1D_32Bit {};
-#ifdef QWORD
+#if defined(uint64_t) || defined(uint64_t_defined)
 class Raster2D_64Bit:virtual public Raster2DAbstract, public Raster1D_64Bit {};
 #endif
 
@@ -407,6 +427,8 @@ class Raster2D_64FltBit:virtual public Raster2DAbstract,public Raster1D_64FltBit
 class Raster2D_8BitRGB: virtual public Raster2DAbstractRGB, virtual public Raster1D_8BitRGB {};
 class Raster2D_16BitRGB: virtual public Raster2DAbstractRGB, virtual public Raster1D_16BitRGB {};
 
+class Raster2D_16Bit565: virtual public Raster2DAbstractRGB, virtual public Raster1D_16Bit565 {};
+
 class Raster2D_8BitRGBA: virtual public Raster2DAbstractRGBA, virtual public Raster1D_8BitRGBA {};
 class Raster2D_16BitRGBA: virtual public Raster2DAbstractRGBA, virtual public Raster1D_16BitRGBA {};
 
@@ -421,7 +443,7 @@ class Raster3D_8Bit: virtual public Raster3DAbstract, public Raster2D_8Bit {};
 class Raster3D_16Bit: virtual public Raster3DAbstract, public Raster2D_16Bit {};
 class Raster3D_24Bit: virtual public Raster3DAbstract, public Raster2D_24Bit {};
 class Raster3D_32Bit: virtual public Raster3DAbstract, public Raster2D_32Bit {};
-#ifdef QWORD
+#if defined(uint64_t) || defined(uint64_t_defined)
 class Raster3D_64Bit: virtual public Raster3DAbstract, public Raster2D_64Bit {};
 #endif
 
