@@ -1587,6 +1587,40 @@ const int count = VectorObjects;
 }
 
 
+bool VectorList::ReplaceObject(VectorObject *OrigObj, VectorObject *NewObj)
+{
+VectorObject *IterObject;
+  if(OrigObj==NULL || OrigObj==NewObj) return false;
+  if(FirstObject==NULL) return false;
+
+  if(FirstObject==OrigObj)
+  {
+    FirstObject = NewObj;
+    NewObj->NextObject = OrigObj->NextObject;
+    if(LastObject==OrigObj) LastObject=NewObj;
+    return true;
+  }
+
+  IterObject = FirstObject;
+  while(IterObject->NextObject!=NULL)
+  {
+    if(IterObject->NextObject==OrigObj)
+    {
+      IterObject->NextObject = NewObj;
+      NewObj->NextObject = OrigObj->NextObject;
+      if(LastObject==OrigObj) LastObject=NewObj;
+      return true;
+    }
+    if(IterObject->NextObject->ReplaceObject(OrigObj,NewObj))
+    {
+      return true;
+    }
+    IterObject = IterObject->NextObject;
+  }
+return false;
+}
+
+
 /////////////////////////////////////////////////////////////
 
 
