@@ -318,6 +318,7 @@ public:
   virtual void FeaturesEPS(uint32_t & Feature) const {return;}
   virtual unsigned isInside(float xp, float yp) const {return 0;}
   virtual VectorObject *Duplicate(void)const = 0;
+  virtual bool ReplaceObject(VectorObject *OrigObj, VectorObject *NewObj) {return false;}
 #ifdef _DEBUG
   virtual void Dump2File(FILE *F) const {}
 #endif
@@ -358,12 +359,14 @@ public:
   virtual ~VectorList();
 
   void AddObject(VectorObject *NewObj);
-  virtual void CalcBoundingBox(FloatBBox &bbx) const;
-  virtual void Transform(const AbstractTransformXY &Tx);
+  virtual bool ReplaceObject(VectorObject *OrigObj, VectorObject *NewObj);
   void Append(VectorList &VectList);
   void Swap(VectorList &VectList);
   virtual VectorObject *Duplicate(void) const;
 
+  virtual void CalcBoundingBox(FloatBBox &bbx) const;
+  virtual void Transform(const AbstractTransformXY &Tx);
+
   VectorObject *FirstObject;
   VectorObject *LastObject;
   int VectorObjects;
