@@ -31,16 +31,16 @@
 
 typedef struct
      {
-     WORD dx;
-     WORD dy;
+     uint16_t dx;
+     uint16_t dy;
      } Tnudge;
 
 class TconvertedPass1_MTF:public TconvertedPass1
      {
 public:
      string Formula;
-     WORD Version;
-     BYTE MTEF_Version;
+     uint16_t Version;
+     uint8_t MTEF_Version;
      Tnudge nudge;
 
      virtual int Convert_first_pass(void);
@@ -523,14 +523,14 @@ const char *Template_EMBELLS[] = {
 
 
 
-static DWORD GetSize(TconvertedPass1 *cq)
+static uint32_t GetSize(TconvertedPass1 *cq)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#GetSize() ");fflush(cq->log);
 #endif
-BYTE SizeTag;
-BYTE test;
-DWORD New_Size=0;
+uint8_t SizeTag;
+uint8_t test;
+uint32_t New_Size=0;
 
  SizeTag=cq->by & 0x0F;
 
@@ -571,7 +571,7 @@ return New_Size;
 
 
 
-static BYTE GetNblByte(TconvertedPass1 *cq,BYTE & Nibble)
+static uint8_t GetNblByte(TconvertedPass1 *cq,uint8_t & Nibble)
 {
  if(Nibble==0)
 	{
@@ -584,12 +584,12 @@ static BYTE GetNblByte(TconvertedPass1 *cq,BYTE & Nibble)
 }
 
 
-static DWORD GetNblSize(TconvertedPass1 *cq,BYTE & Nibble)
+static uint32_t GetNblSize(TconvertedPass1 *cq,uint8_t & Nibble)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#GetNblSize() ");fflush(cq->log);
 #endif
-BYTE Tag,B;
+uint8_t Tag,B;
 int i;
 
   Tag=GetNblByte(cq,Nibble);
@@ -623,11 +623,11 @@ static void MTEF_LINE(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#MTEF_LINE() ");fflush(cq->log);
 #endif
-BYTE OldBy, Ruller;
-SWORD LineSpacing;
+uint8_t OldBy, Ruller;
+int16_t LineSpacing;
 
- static int LineNo = 0;
- int iLineNo = LineNo++;
+ static int LineNumber = 0;
+ int iLineNo = LineNumber++;
 
  if(cq->Version<=0x3FF)
       {
@@ -639,7 +639,7 @@ SWORD LineSpacing;
  else {
       cq->subby=fgetc(cq->wpd);	//[options]
       if(cq->subby & MtefO_NUDGE) Rd_nudge(cq->wpd, cq->nudge);
-      if(cq->subby & MtefO_LINE_LSPACE) Rd_word(cq->wpd, (WORD *)&LineSpacing);
+      if(cq->subby & MtefO_LINE_LSPACE) Rd_word(cq->wpd, (uint16_t *)&LineSpacing);
       if(cq->subby & MtefO_LINE_NULL) {sprintf(cq->ObjType, "LINE{}");return;}
       }
 
@@ -667,7 +667,7 @@ static void MTEF_EMBELL(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#MTEF_EMBELL() ");fflush(cq->log);
 #endif
-BYTE Embell,OldBy;
+uint8_t Embell,OldBy;
 const char *TemplateStr, *str2;
 string StrB,StrE;
 string arg[4];
@@ -728,11 +728,11 @@ static void MTEF_TMPL(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#MTEF_TMPL() ");fflush(cq->log);
 #endif
-WORD Variation;
-BYTE Selector,Options;
+uint16_t Variation;
+uint8_t Selector,Options;
 string StrB,StrE,arg[5];
 const char *TemplateStr, *str2;
-BYTE OldBy;
+uint8_t OldBy;
 int i;
 char Num[2]="0";
 
@@ -822,8 +822,8 @@ static void MTEF_PILE(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#MTEF_PILE() ");fflush(cq->log);
 #endif
-BYTE Halign,Valign;
-BYTE Ruler;
+uint8_t Halign,Valign;
+uint8_t Ruler;
 
   if(cq->Version<=0x3FF)
       {
@@ -851,9 +851,9 @@ static void MTEF_MATRIX(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#MTEF_MATRIX() ");fflush(cq->log);
 #endif
-SBYTE OldBy;
-BYTE x,y;
-BYTE Valign,h_just,v_just,rows,cols;
+int8_t OldBy;
+uint8_t x,y;
+uint8_t Valign,h_just,v_just,rows,cols;
 Raster1DAbstract *row_parts=NULL,*col_parts=NULL;
 
   if(cq->Version<=0x3FF)
@@ -979,7 +979,7 @@ static void MTEF_RULER(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#MTEF_RULER() ");fflush(cq->log);
 #endif
-BYTE Tabs;
+uint8_t Tabs;
 
   if(cq->Version<=0x3FF) cq->subby=cq->by>>4;
   else cq->subby=0;
@@ -996,8 +996,8 @@ static void MTEF_FONTSTYLE(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#MTEF_FONTSTYLE() ");fflush(cq->log);
 #endif
-WORD DefIndex;
-BYTE CharStyle,Tface;
+uint16_t DefIndex;
+uint8_t CharStyle,Tface;
 char c;
 
   if(cq->Version<=0x3FF)
@@ -1026,8 +1026,8 @@ static void MTEF_CHAR(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#MTEF_CHAR() ");fflush(cq->log);
 #endif
-WORD CHAR;
-SBYTE Typeface;
+uint16_t CHAR;
+int8_t Typeface;
 const char *ChrStr;
 
   if(cq->Version<=0x3FF)
@@ -1038,9 +1038,9 @@ const char *ChrStr;
       if(cq->MTEF_Version<=2)
 		{
 		CHAR=fgetc(cq->wpd);
-		CHAR+=256*(WORD)Typeface;
+		CHAR+=256*(uint16_t)Typeface;
 		}
-	   else Rd_word(cq->wpd, (WORD *)&CHAR);
+	   else Rd_word(cq->wpd, (uint16_t *)&CHAR);
       }
   else
      {
@@ -1050,7 +1050,7 @@ const char *ChrStr;
 
      if(cq->subby & MtefO_CHAR_ENC_CHAR_8) CHAR=fgetc(cq->wpd);
      else {
-	  Rd_word(cq->wpd, (WORD *)&CHAR);
+	  Rd_word(cq->wpd, (uint16_t *)&CHAR);
 	  }
      }
 
@@ -1093,8 +1093,8 @@ void ProcessKeyMTEFSymbol(TconvertedPass1_MTF *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#ProcessKeyMTEFSymbol() ");fflush(cq->log);
 #endif
-BYTE size,by;
-BYTE Nibble;
+uint8_t size,by;
+uint8_t Nibble;
 
  *cq->ObjType = '\0';
 
@@ -1171,7 +1171,7 @@ int TconvertedPass1_MTF::Convert_first_pass(void)
 #ifdef DEBUG
   fprintf(log,"\n#Convert_pass1_MTEF() ");fflush(log);
 #endif
-DWORD fsize;
+uint32_t fsize;
 TBox Box;
 bool Line=false;
 
