@@ -7,6 +7,7 @@
  * licency:     GPL		                                              *
  ******************************************************************************/
 // https://www.w3schools.com/graphics/svg_intro.asp
+// https://developer.mozilla.org/en-US/docs/Web/SVG/Attribute/d#path_commands
 #include<stdio.h>
 #include<string.h>
 #include<stdlib.h>
@@ -42,9 +43,27 @@ extern list HTMLChars;
 int SavePictureEPS(const char *Name, const Image &Img);
 
 
+class ForwardHolder: public VectorObject
+{
+public:
+    ForwardHolder(const char *Key, float NewX, float NewY): x(NewX), y(NewY), KeyHook(Key) {};
+
+    virtual VectorObject *Duplicate(void) const;
+
+    float x,y;
+    string KeyHook;
+};
+
+
+VectorObject *ForwardHolder::Duplicate(void) const
+{
+  return new ForwardHolder(KeyHook(),x,y);
+}
+
+
 /// Read float value from in memory string.
-/// @param[in,out] pstr	Pointerto a stringto be read.
-/// @param[out] f	Value read.
+/// @param[in,out]	pstr	Pointer to a string to be read.
+/// @param[out]		f	Value read.
 /// @return	true on success, false on failure.
 bool ReadFloat(const char **pstr, float &f)
 {
@@ -126,11 +145,12 @@ typedef enum
 	SVG_POLYLINE = 134,
 	SVG_POLYGON = 135,
 	SVG_PATH = 136,
-	SVG_G = 137,
-	SVG_TEXT = 138,
-	SVG_DEFS = 139,
-	SVG_USE = 140,
-	SVG_IMAGE
+	SVG_G,
+	SVG_TEXT,
+	SVG_DEFS,
+	SVG_USE,
+	SVG_IMAGE,
+	SVG_STYLE
 } E_SVG_TAGS;
 
 
@@ -139,31 +159,39 @@ class TconvertedPass1_SVG: virtual public TconvertedPass1_XML, virtual public Tc
      {
 protected:
      VectorList VectList;
+     doublelist StyleDict;
      PS_State PSS;
      float PositionX, PositionY;
 
      DefinedObject **objs;
      int DObjectCount;
+     ForwardHolder **DelayedObjects;
+     int DelayedObjCount;
 
      bool GetProp(const char *PropName, float &f);
      bool GetColor(RGB_Record &LineColor, const char *ClrType=LINE_COLOR);
      void GetLineCap(unsigned char &LineCap);
      void GetLineJoin(unsigned char &LineJoin);
      void GetStyle(vecPen *pPen, vecBrush *pBrush);
+     void GetStyle(vecPen *pPen, vecBrush *pBrush, const char * const Payload);
      float *LoadPoints(int &n);
      AbstractTransformXY *getTransform(void);
      void ClosePathLine(float **pPoints, int & n, bool Close=false, AbstractTransformXY *Tx=NULL);
      void ClosePathCurve(float **pPoints, int & n, bool Close=false, AbstractTransformXY *Tx=NULL);
 
 public:
-     TconvertedPass1_SVG(void)	{DObjectCount=0;objs=NULL;}
-     virtual ~TconvertedPass1_SVG(void);
+     TconvertedPass1_SVG(void)	{DelayedObjCount=DObjectCount=0;objs=NULL;DelayedObjects=NULL;}
+     virtual ~TconvertedPass1_SVG(void) {EraseObjCache();}
+
      void AddDefine(DefinedObject *pObj);
+     void EraseObjCache(void);
      DefinedObject *GetDefine(const char *DefId);
+     void AddDelayedObject(ForwardHolder *pFwdObj);
 
      virtual int Convert_first_pass(void);
      void ProcessKeySVG(void);
      void ProcessImage(void);
+     void SolveDelayedObjs(void);
 
      void Circle(void);
      void Defs(void);
@@ -175,6 +203,7 @@ public:
      void Polygon(void);
      void PolyLine(void);
      void Rectangle(void);
+     void Style(void);
      void Text(void);
      void Use(void);
 
@@ -194,10 +223,10 @@ ImplementReader(SVG,".SVG")
    LoadPictureSVG,
    NULL);
 
-#define SVGVersion "0.5"
+#define SVGVersion "0.6"
 
 
-TconvertedPass1_SVG::~TconvertedPass1_SVG()
+void TconvertedPass1_SVG::EraseObjCache(void)
 {
   if(objs)
   {
@@ -213,6 +242,13 @@ TconvertedPass1_SVG::~TconvertedPass1_SVG()
     free(objs);
     objs = NULL;
   }
+  if(DelayedObjects)
+  {
+	// Objects are double referenced, do not erase them from this list.
+    DelayedObjCount = 0;
+    free(DelayedObjects);
+    DelayedObjects = NULL;
+  }
 }
 
 
@@ -244,6 +280,34 @@ void TconvertedPass1_SVG::AddDefine(DefinedObject *pObj)
 }
 
 
+void TconvertedPass1_SVG::AddDelayedObject(ForwardHolder *pFwdObj)
+{
+  if(DelayedObjects==NULL)
+  {
+    DelayedObjects = (ForwardHolder**)malloc(sizeof(ForwardHolder*));
+    if(DelayedObjects==NULL)
+    {
+      //delete pObj;	No delete
+      return;
+    }
+    DelayedObjCount = 1;
+  }
+  else
+  {
+    DelayedObjCount++;
+    void *NewObjs = realloc(DelayedObjects, DelayedObjCount*sizeof(ForwardHolder*));
+    if(NewObjs==NULL)
+    {
+      DObjectCount--;
+      //delete pObj;
+      return;
+    }
+    DelayedObjects = (ForwardHolder**)NewObjs;
+  }
+  DelayedObjects[DelayedObjCount-1] = pFwdObj;
+}
+
+
 DefinedObject *TconvertedPass1_SVG::GetDefine(const char *DefId)
 {
   if(objs==NULL) return NULL;
@@ -354,6 +418,19 @@ bool GetStyleColor(RGB_Record *pColor, const char *ClrText)
     return false;
   }
 
+  if(*ClrText=='#')
+  {
+    ClrText++;
+    while(isspace(*ClrText)) ClrText++;
+    if(*ClrText==0) return false;
+    unsigned number = strtoul(ClrText, NULL, 16);
+    pColor->Blue = number & 0xFF;
+    pColor->Green = (number>>8) & 0xFF;
+    pColor->Red = (number>>16) & 0xFF;
+    return true;
+  }
+
+	// Look into a color dictionary.
   string Color;
   while(isalpha(*ClrText))
   {
@@ -404,12 +481,9 @@ int i;
 }
 
 
-void TconvertedPass1_SVG::GetStyle(vecPen *pPen, vecBrush *pBrush)
+void TconvertedPass1_SVG::GetStyle(vecPen *pPen, vecBrush *pBrush, const char * const Payload)
 {
-int i;
 const char *str;
-  if((i=TAG_Args IN "style")<0) return;
-  const char * const Payload = TAG_Args.Member(i,1);
   if(Payload==NULL) return;
   if(pPen)
   {
@@ -440,6 +514,23 @@ const char *str;
 }
 
 
+void TconvertedPass1_SVG::GetStyle(vecPen *pPen, vecBrush *pBrush)
+{
+int i;
+  if((i=TAG_Args IN "style")>=0)
+    GetStyle(pPen, pBrush, TAG_Args.Member(i,1));
+
+  if((i=TAG_Args IN "class")>=0)
+  {
+    const char * Payload = TAG_Args.Member(i,1);
+    if(Payload!=NULL)
+    {
+      GetStyle(pPen, pBrush, StyleDict.Find(Payload));
+    }
+  }
+}
+
+
 float *TconvertedPass1_SVG::LoadPoints(int &n)
 {
 int i;
@@ -833,6 +924,78 @@ strcpy(ObjType,"Group");
 }
 
 
+void TconvertedPass1_SVG::Style(void)
+{
+#ifdef DEBUG
+  fprintf(log,"\n#TconvertedPass1_SVG::Style ");fflush(log);
+#endif
+char status = 0;
+string key, commands;
+
+  recursion++;
+  while(!feof(wpd))
+  {
+    ReadXMLTag(false);
+    if(by==XML_closetag && TAG=="</style>")
+        break;
+    if(by==XML_char)
+    {
+      switch(status)
+      {
+        case 0: if(subby=='.')
+                {
+                  key.erase();
+                  commands.erase();
+                  status = 1;
+                  break;
+                }
+        case 1: if(subby=='{')
+                {
+                  status = 2;
+                  break;
+                }
+                if(key.length() > 1024)
+                {
+                  if(err != NULL)
+                  {
+                    perc.Hide();
+                    fprintf(err,_("\nError: Style key is too big: \"%s\"."),key());
+                  }
+                  status = 127;
+                  break;
+                }
+                key += subby;
+                break;
+        case 2: if(subby=='}')
+                {
+                  StyleDict.Add(key(), commands());
+                  status = 0;
+                  break;
+                }
+                if(commands.length() > 4096)
+                {
+                  if(err != NULL)
+                  {
+                    perc.Hide();
+                    fprintf(err,_("\nError: Style contents is too big: \"%s\"."),commands());
+                  }
+                  status = 127;
+                  break;
+                }
+                commands += subby;
+                break;
+        case 127: break;
+     }
+      continue;
+    }
+    ProcessKeySVG();
+  }
+  recursion--;
+
+  strcpy(ObjType,"Style");
+}
+
+
 void TconvertedPass1_SVG::Text(void)
 {
 #ifdef DEBUG
@@ -899,7 +1062,7 @@ const float FontSizeBk = PSS.FontSize;
 
   PSS.TextColor = BkTextColor;
   PSS.FontSize = FontSizeBk;
-strcpy(ObjType,"Group");
+strcpy(ObjType,"Text");
 }
 
 
@@ -1848,11 +2011,17 @@ TransformSVG *pTx = NULL;
   if((i=TAG_Args IN "xlink:href")>=0)
   {
     const char * const Payload = TAG_Args.Member(i,1);
-    if(Payload==NULL) goto ExitFail;
+    if(Payload==NULL || *Payload==0) goto ExitFail;
     if(Payload[0]!='#') goto ExitFail;
 
     const DefinedObject *pDObj = GetDefine(Payload+1);
-    if(pDObj==NULL) goto ExitFail;
+    if(pDObj==NULL)		// The object was not found in SVG dictionary.
+    {				// try to postpone processing.
+      ForwardHolder *pFwdObj = new ForwardHolder(Payload+1, x, y);
+      AddDelayedObject(pFwdObj);
+      VectList.AddObject(pFwdObj);
+      goto ExitFail;
+    }
     VectorObject *pObj = pDObj->VectList.Duplicate();
     if(pObj==NULL) goto ExitFail;
 
@@ -1938,7 +2107,8 @@ uint8_t by, subby;
 	       if(loc_TAG=="g")       {by=SVG_G;break;}
 	       if(loc_TAG=="text")    {by=SVG_TEXT;break;}
 	       if(loc_TAG=="defs")    {by=SVG_DEFS;break;}
-               if(loc_TAG=="use")     {by=SVG_USE;break;}
+	       if(loc_TAG=="use")     {by=SVG_USE;break;}
+	       if(loc_TAG=="style")   {by=SVG_STYLE;break;}
 	       break;
 	case XML_closetag:
                loc_TAG = copy(TAG,2,length(TAG)-3);	//Closing tag </xxx>
@@ -1982,6 +2152,7 @@ uint8_t by, subby;
 	case SVG_DEFS:Defs(); break;
 	case SVG_USE:Use(); break;
 	case SVG_IMAGE: ImageEmbed(); break;
+	case SVG_STYLE: Style(); break;
 	}
 
 
@@ -2050,6 +2221,35 @@ void TconvertedPass1_SVG::ProcessImage(void)
 }
 
 
+void TconvertedPass1_SVG::SolveDelayedObjs(void)
+{
+  for(int i=0; i<DelayedObjCount; i++)
+  {
+    ForwardHolder *pObj = DelayedObjects[i];
+    if(pObj==NULL) continue;
+
+    const DefinedObject *pDefDObj = GetDefine(pObj->KeyHook());
+    if(pDefDObj)
+    {
+      VectorObject *Replacement = pDefDObj->VectList.Duplicate();
+      if(pObj->x!=0 || pObj->y!=0)
+      {
+        TransformSVG *pTx = new TransformSVG;
+        pTx->CTM(3,0) = pObj->x;
+        pTx->CTM(3,1) = pObj->y;
+        Replacement->Transform(*pTx);	// Apply shift x,y operation.
+      }
+      if(!VectList.ReplaceObject(pObj,Replacement))
+          delete Replacement;		// Not found, should not occur.
+      delete pObj;			// pObj is either replacet or not found, erase it.
+    }
+    // else pObj could be still referenced.
+    DelayedObjects[i] = NULL;
+  }
+  EraseObjCache();
+}
+
+
 int TconvertedPass1_SVG::Convert_first_pass(void)
 {
 #ifdef DEBUG
@@ -2080,6 +2280,7 @@ int RetVal = 0;
       TAG.erase();
       ProcessKeySVG();
       }
+  SolveDelayedObjs();
 
   ProcessImage();
 
@@ -2152,6 +2353,7 @@ size_t fsize;
       fclose(ConvSvg.wpd);
       ConvSvg.wpd = NULL;
 
+      ConvSvg.SolveDelayedObjs();
       ConvSvg.ProcessImage();
     }
   }
