@@ -951,7 +951,7 @@ int Status, CharNo=0, chr;
 
   Status=0;
   fseek(text,0,SEEK_SET);
-  while(CharNo<1024)		// SVG header might be very big with comments.
+  while(CharNo<1400)		// SVG header might be very big with comments.
 	{
 	if( (chr=fgetc(text)) == EOF) goto NoSVG;
 	chr=toupper(chr);
@@ -996,7 +996,10 @@ int Status, CharNo=0, chr;
 		       goto NoSVG;
 
 		case 101:if(chr=='>') Status=0;
+		       if(chr=='[') Status=102;
 		       break;
+		case 102: if(chr==']') Status=101;
+		      break;
 		default:printf(_("Error: State automat failed at state %d\n"),Status);
 			Status=0;
 		}
