@@ -9,7 +9,7 @@
 
 
 #ifndef __TYPES_INCLUDED
- #include "typedfs.h"		/*File defines BYTE, WORD, DWORD types*/
+ #include "typedfs.h"		/*Define types for BYTE, WORD, DWORD ...*/
 #endif
 #ifndef __Common_H_INCLUDED
  #include "common.h"		/*File defines compiler dependent features*/
@@ -17,11 +17,11 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"4.2"
-#define VersionDate	"28 Sep 2023"  /* day (space) month (space) full year */
+#define VersionWP2L	"4.3"
+#define VersionDate	"31 Oct 2023"  /* day (space) month (space) full year */
 
 
-/* Constants for a flag InputPS */
+/** Constants for a flag InputPS */
 typedef enum
 {
     IMG_InputPS	=	0,
